pub struct ScalarSignature { /* private fields */ }Expand description
One overload of a scalar function: a parameter shape and a return type.
Implementations
Sourceimpl ScalarSignature
impl ScalarSignature
Sourcepub fn exact(parameters: Vec<LogicalType>, return_type: LogicalType) -> Self
pub fn exact(parameters: Vec<LogicalType>, return_type: LogicalType) -> Self
A signature with a fixed list of parameter types.
Sourcepub fn variadic(parameter: LogicalType, return_type: LogicalType) -> Self
pub fn variadic(parameter: LogicalType, return_type: LogicalType) -> Self
A signature accepting any number of arguments of parameter’s type.